A selective view of key components in Raft Engine. Exported under the
internals feature only.
Modules
- debug
- A set of public utilities used for interacting with log files.
Structs
- Default
Machine Factory - A factory of
ReplayMachines that can be default constructed. - Entry
Index - Location of a log entry.
- File
Block Handle - A logical pointer to a chunk of log file data.
- FileId
- A unique identifier for a log file.
- File
Pipe Log - A
PipeLogimplementation that stores data in filesystem. - File
Pipe LogBuilder DualPipesfactory that can also recover other customized memory states.- LogFile
Context - MemTable
- In-memory storage for Raft Groups.
- MemTable
Accessor - A collection of
MemTables. - MemTable
Recover Context - MemTable
Recover Context Factory - Purge
Hook - Purge
Manager - Recovery
Config - Container for basic settings on recovery.
- Version
Iter - An iterator over the variants of Version
- Write
Barrier - A synchronizer of
Writers. - Write
Group - A collection of writers. User thread (leader) that receives a
WriteGroupis responsible for processing its containing writers. - Writer
- Writer
Iter - An iterator over the
Writers in oneWriteGroup.
Enums
Traits
- Event
Listener EventListenercontains a set of callback functions that will be notified on specific events inside Raft Engine.- File
Name Ext FileNameExtoffers file name formatting extensions toFileId.- PipeLog
- A
PipeLogserves reads and writes over multiple queues of log files. - Reactive
Bytes - Some bytes whose value might be dependent on the file it is written to.
- Replay
Machine ReplayMachineis a type of deterministic state machine that obeys associative law.
Functions
Type Aliases
- FileSeq
- Sequence number for log file. It is unique within a log queue.
- MemTable
Handle - MemTables