Module debug

Module debug 

A set of public utilities used for interacting with log files.

Structs

LogItemReader
An iterator over the log items in log files.

Functions

build_file_reader
Opens a log file for read.
build_file_writer
Opens a log file for write. When create is true, the specified file will be created first if not exists.