pub struct FileBlockHandle {
pub id: FileId,
pub offset: u64,
pub len: usize,
}Expand description
A logical pointer to a chunk of log file data.
Fields
id: FileIdoffset: u64len: usizeTrait Implementations
Sourceimpl Clone for FileBlockHandle
impl Clone for FileBlockHandle
Sourcefn clone(&self) -> FileBlockHandle
fn clone(&self) -> FileBlockHandle
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for FileBlockHandle
Sourceimpl Debug for FileBlockHandle
impl Debug for FileBlockHandle
impl Eq for FileBlockHandle
Sourceimpl PartialEq for FileBlockHandle
impl PartialEq for FileBlockHandle
Sourcefn eq(&self, other: &FileBlockHandle) -> bool
fn eq(&self, other: &FileBlockHandle) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for FileBlockHandle