A set of public utilities used for interacting with log files.
Structs
- LogItem
Reader - An iterator over the log items in log files.
Functions
- build_
file_ reader - Opens a log file for read.
- build_
file_ writer - Opens a log file for write. When
createis true, the specified file will be created first if not exists.